==> webdriver-2.0.0.tar.gz: test/async_navigation_test.dart <==
// Copyright 2015 Google Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

@TestOn('vm')
library webdriver.navigation_test;

import 'package:test/test.dart';
import 'package:webdriver/support/async.dart';
import 'package:webdriver/async_core.dart';

import 'io_config.dart' as config;

void main() {
  group('Navigation', () {
    WebDriver driver;

    setUp(() async {
      driver = await config.createTestDriver();
      await driver.get(config.testPagePath);
    });

    tearDown(() async {
      if (driver != null) {
        await driver.quit();
      }
      driver = null;
    });

    test('refresh', () async {
      var element = await driver.findElement(const By.tagName('button'));
      await driver.navigate.refresh();
      await waitFor(() async {
        try {
          await element.name;
        } on StaleElementReferenceException {
          return true;
        }
        return 'expected StaleElementReferenceException';
      });
    });
  }, timeout: const Timeout(const Duration(minutes: 2)));
}

==> webdriver-2.1.0.tar.gz: test/async_navigation_test.dart <==
// Copyright 2015 Google Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

@TestOn('vm')
library webdriver.navigation_test;

import 'dart:io';

import 'package:test/test.dart';
import 'package:webdriver/async_core.dart';
import 'package:webdriver/support/async.dart';

import 'configs/async_io_config.dart' as config;

void main() {
  group('Navigation', () {
    WebDriver driver;
    HttpServer server;

    setUp(() async {
      driver = await config.createTestDriver();
      server = await config.createTestServerAndGoToTestPage(driver);
    });

    tearDown(() async {
      await driver?.quit();
      await server?.close(force: true);
    });

    test('refresh', () async {
      var element = await driver.findElement(const By.tagName('button'));
      await driver.refresh();
      await waitFor(() async {
        try {
          await element.name;
        } on StaleElementReferenceException {
          return true;
        }
        return 'expected StaleElementReferenceException';
      });
    });
  }, timeout: const Timeout(Duration(minutes: 2)));
}
